@@ -503,8 +503,8 @@ impl<'a, X: PlotNum, Y: PlotNum> Plotter<'a, X, Y> {
     /// let mut k=String::new();
     /// plotter.render(&mut k);
     /// ```
-    pub fn render<T: std::fmt::Write>(&mut self, a: T) {
-        render::render(self, a);
+    pub fn render<T: std::fmt::Write>(&mut self, a: T) -> fmt::Result {
+        render::render(self, a)
     }
 
     ///
@@ -517,15 +517,14 @@ impl<'a, X: PlotNum, Y: PlotNum> Plotter<'a, X, Y> {
     /// let mut k=String::new();
     /// plotter.simple_theme(&mut k);
     /// ```
-    pub fn simple_theme<T: std::fmt::Write>(&mut self, mut a: T) {
+    pub fn simple_theme<T: std::fmt::Write>(&mut self, mut a: T) -> std::fmt::Result {
         write!(
             &mut a,
             "{}<style>{}</style>",
             SVG_HEADER, STYLE_CONFIG_LIGHT_DEFAULT
-        )
-        .unwrap();
-        self.render(&mut a);
-        write!(&mut a, "{}", SVG_END).unwrap();
+        )?;
+        self.render(&mut a)?;
+        write!(&mut a, "{}", SVG_END)
     }
 
     ///
@@ -538,15 +537,14 @@ impl<'a, X: PlotNum, Y: PlotNum> Plotter<'a, X, Y> {
     /// let mut k=String::new();
     /// plotter.simple_theme_dark(&mut k);
     /// ```
-    pub fn simple_theme_dark<T: std::fmt::Write>(&mut self, mut a: T) {
+    pub fn simple_theme_dark<T: std::fmt::Write>(&mut self, mut a: T) -> std::fmt::Result {
         write!(
             &mut a,
             "{}<style>{}</style>",
             SVG_HEADER, STYLE_CONFIG_DARK_DEFAULT
-        )
-        .unwrap();
-        self.render(&mut a);
-        write!(&mut a, "{}", SVG_END).unwrap();
+        )?;
+        self.render(&mut a)?;
+        write!(&mut a, "{}", SVG_END)
     }
 }
 /*
@@ -591,7 +589,7 @@ impl<F: Fn(&mut fmt::Formatter) -> fmt::Result> fmt::Display for DisplayableClos
 ///
 /// Leverage rust's display format system using `RefCell` under the hood.
 ///
-pub fn disp_mut<F: FnMut(&mut fmt::Formatter)>(a: F) -> DisplayableClosureMut<F> {
+pub fn disp_mut<F: FnMut(&mut fmt::Formatter) -> fmt::Result>(a: F) -> DisplayableClosureMut<F> {
     DisplayableClosureMut::new(a)
 }
 
@@ -602,15 +600,14 @@ use std::cell::RefCell;
 ///
 pub struct DisplayableClosureMut<F>(pub RefCell<F>);
 
-impl<F: FnMut(&mut fmt::Formatter)> DisplayableClosureMut<F> {
+impl<F: FnMut(&mut fmt::Formatter) -> fmt::Result> DisplayableClosureMut<F> {
     pub fn new(a: F) -> Self {
         DisplayableClosureMut(RefCell::new(a))
     }
 }
-impl<F: FnMut(&mut fmt::Formatter)> fmt::Display for DisplayableClosureMut<F> {
+impl<F: FnMut(&mut fmt::Formatter) -> fmt::Result> fmt::Display for DisplayableClosureMut<F> {
     fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
-        (self.0.borrow_mut())(formatter);
-        Ok(())
+        (self.0.borrow_mut())(formatter)
     }
 }
 
